package com.zkqy.system.service.impl;

import java.util.List;

import com.zkqy.system.entity.MobilePageData;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zkqy.system.mapper.MobilePageDataMapper;
import com.zkqy.system.service.IMobilePageDataService;

/**
 * 移动端数据Service业务层处理
 * 
 * @author zkqy
 * @date 2024-04-18
 */
@Service
public class MobilePageDataServiceImpl implements IMobilePageDataService 
{
    @Autowired
    private MobilePageDataMapper mobilePageDataMapper;

    /**
     * 查询移动端数据
     * 
     * @param id 移动端数据主键
     * @return 移动端数据
     */
    @Override
    public MobilePageData selectMobilePageDataById(Long id)
    {
        return mobilePageDataMapper.selectMobilePageDataById(id);
    }

    /**
     * 查询移动端数据列表
     * 
     * @param mobilePageData 移动端数据
     * @return 移动端数据
     */
    @Override
    public List<MobilePageData> selectMobilePageDataList(MobilePageData mobilePageData)
    {
        return mobilePageDataMapper.selectMobilePageDataList(mobilePageData);
    }

    /**
     * 新增移动端数据
     * 
     * @param mobilePageData 移动端数据
     * @return 结果
     */
    @Override
    public int insertMobilePageData(MobilePageData mobilePageData)
    {
        return mobilePageDataMapper.insertMobilePageData(mobilePageData);
    }

    /**
     * 修改移动端数据
     * 
     * @param mobilePageData 移动端数据
     * @return 结果
     */
    @Override
    public int updateMobilePageData(MobilePageData mobilePageData)
    {
        return mobilePageDataMapper.updateMobilePageData(mobilePageData);
    }

    /**
     * 批量删除移动端数据
     * 
     * @param ids 需要删除的移动端数据主键
     * @return 结果
     */
    @Override
    public int deleteMobilePageDataByIds(Long[] ids)
    {
        return mobilePageDataMapper.deleteMobilePageDataByIds(ids);
    }

    /**
     * 删除移动端数据信息
     * 
     * @param id 移动端数据主键
     * @return 结果
     */
    @Override
    public int deleteMobilePageDataById(Long id)
    {
        return mobilePageDataMapper.deleteMobilePageDataById(id);
    }
}
